==> likepoint_payment-0.0.1.tar.gz: lib/ui/payment_confirm/payment_confirm.dart <==
import 'dart:async';
import 'package:intl/intl.dart';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:likepoint_payment/middle_ware/middle_payment.dart';
import 'package:likepoint_payment/provider/payment_confirm_provider.dart';
import 'package:likepoint_payment/text_style.dart';
import 'package:likepoint_payment/ui/custom_loading.dart';
import 'package:likepoint_payment/ui/payment_completed/payment_completed.dart';
import 'package:likepoint_payment/ui/payment_confirm/component/payment_confirm_component.dart';
import 'package:modal_progress_hud/modal_progress_hud.dart';
import 'package:provider/provider.dart';

class PaymentConfirmPage extends StatelessWidget {
  PaymentConfirmPage(
      {this.phone, this.amount, this.billCode, this.bu, this.title});
  final String phone;
  final String amount;
  final String billCode;
  final String bu;
  final String title;

  @override
  Widget build(BuildContext context) {
    return MultiProvider(
      providers: [
        ChangeNotifierProvider.value(value: CreateOrderProvider()),
      ],
      child: PaymentConfirm(
        phone: phone,
        amount: amount,
        billCode: billCode,
        bu: bu,
        title: title,
      ),
    );
  }
}

class PaymentConfirm extends StatefulWidget {
  PaymentConfirm({this.phone, this.amount, this.billCode, this.bu, this.title});

  final String phone;
  final String amount;
  final String billCode;
  final String bu;
  final String title;

  @override
  _PaymentConfirm createState() => _PaymentConfirm();
}

class _PaymentConfirm extends State<PaymentConfirm> {
  TextEditingController controller = TextEditingController();

  //////////////////// MIDDLE WARE /////////////////////////////
  HTTP callHTTP;
  //////////////////// PROVIDER ///////////////////////////////
  CreateOrderProvider _createOrderProvider;

  final f = new DateFormat('dd/MM/yyyy');

  @override
  void initState() {
    // TODO: implement initState
    super.initState();
    callHTTP = CallHTTP();
  }

  @override
  void didChangeDependencies() async {
    super.didChangeDependencies();
    _createOrderProvider = Provider.of<CreateOrderProvider>(context);
  }

  @override
  void dispose() {
    // TODO: implement dispose
    super.dispose();
    // _timer.cancel();
  }

  @override
  Widget build(BuildContext context) {
    ScreenUtil.init(context,
        designSize: Size(1080, 2340), allowFontScaling: false);
    return ModalProgressHUD(
      opacity: 0.5,
      inAsyncCall: _createOrderProvider.getLoading,
      progressIndicator: CustomLoading(),
      child: Scaffold(
        appBar: AppBar(
          backgroundColor: Colors.cyan,
          leading: InkWell(
            onTap: () => {
              Navigator.of(context).pop(),
            },
            child: Icon(
              Icons.clear,
              size: 60.h,
            ),
          ),
          title: Text(
            'ยืนยันการชำระ',
          ),
          actions: [],
        ),
        body: Padding(
          padding: EdgeInsets.symmetric(horizontal: 100.w),
          child: Column(
            mainAxisAlignment: MainAxisAlignment.start,
            crossAxisAlignment: CrossAxisAlignment.start,
            children: <Widget>[
              SizedBox(height: 100.h),

              // SizedBox(height: 100.h),
              PaymentConfirmComponent.iconLikePoint(),

              SizedBox(height: 100.h),
              PaymentConfirmComponent.textLine1(
                  context: context,
                  text:
                      'เพื่อความปลอดภัยในการทำรายการชำระผ่านระบบออนไลน์ด้วย LIKE (Like Point)'),
              SizedBox(height: 18.h),
              PaymentConfirmComponent.textLine2(
                  context: context,
                  text:
                      'โปรดตรวจสอบความถูกต้องของข้อความยืนยันส่วนตัวของท่าน จากนั้นระบุรหัส OTP  (One Time Password)'),
              PaymentConfirmComponent.textLine2(
                  context: context,
                  text: 'เพื่อเพิ่มความปลอดภัยในการทำรายการนี้'),
              SizedBox(height: 40.h),
              detail(
                  textTitle: 'ยอดรวม:', textDetail: widget.amount + '  LIKE'),
              detail(
                  textTitle: 'วันที่ชำระ:',
                  textDetail: f.format(DateTime.now()).toString()),
              detail(
                  textTitle: 'เบอร์โทร:',
                  textDetail: '*******' +
                      widget.phone.substring(widget.phone.length - 3)),
              detail(textTitle: 'ข้อความ:', textDetail: widget.title),
              SizedBox(height: 40.h),
              PaymentConfirmComponent.textLine5(
                  context: context,
                  text:
                      'กรุณากดปุ่ม  "Request OTP" เพื่อรับรหัสรักษาความปลอดภัย SMS-OTP'),
              SizedBox(height: 40.h),
              cardOTP(),
              SizedBox(height: 100.h),
              buttonAction(),
              SizedBox(height: 100.h),
              PaymentConfirmComponent.textLine5(
                  context: context,
                  text:
                      'กรณีท่านต้องการเปลี่ยนแปลงหมายเลขโทรศัพท์มือถือที่รับ OTP บริการชำระ LikePoint ได้ที่ APP Like Wallet สอบถามทีมสนับสนุน หรือ สอบถามรายละเอียดเพิ่มเติมได้ที่ \nโทร 098-0977-784 ต่อ 405'),
              SizedBox(height: 40.h),
            ],
          ),
        ),
      ),
    );
  }

  Widget detail({String textTitle, String textDetail}) {
    return Container(
      child: Row(
        children: [
          Expanded(
            child: Align(
              alignment: Alignment.centerRight,
              child: PaymentConfirmComponent.textLine3(
                  context: context, text: textTitle),
            ),
          ),
          SizedBox(width: 20.w),
          Expanded(
            child: Align(
              alignment: Alignment.centerLeft,
              child: PaymentConfirmComponent.textLine4(
                  context: context, text: textDetail),
            ),
          ),
        ],
      ),
    );
  }

  Widget cardOTP() {
    return Container(
        decoration: BoxDecoration(border: Border.all(color: Colors.black12)),
        height: 300.h,
        width: MediaQuery.of(context).size.width,
        child: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          children: [
            PaymentConfirmComponent.textLine3(
                context: context,
                text: 'กรุณาระบุรหัสรักษาความปลอดภัย SMS-OTP ที่ได้รับ'),
            SizedBox(height: 20.h),
            Container(
                height: 80.h,
                width: 250.w,
                child: TextField(
                  controller: controller,
                  keyboardType: TextInputType.number,
                  textAlign: TextAlign.center,
                  textAlignVertical: TextAlignVertical.center,
                  inputFormatters: <TextInputFormatter>[
                    FilteringTextInputFormatter.digitsOnly,
                    LengthLimitingTextInputFormatter(6),
                  ], // Only numbers
                  style: TextStyleCustom.textStyleNG30(context),
                  decoration: InputDecoration(
                    isDense: true,
                    border: OutlineInputBorder(),
                    contentPadding: EdgeInsets.only(top: 20.h, bottom: 20.h),
                  ),
                )),
            SizedBox(height: 20.h),
            Row(
              mainAxisAlignment: MainAxisAlignment.center,
              children: [
                SizedBox(
                  height: 70.h,
                  child: RaisedButton(
                    child: Text(
                      _createOrderProvider.getStatusOTP
                          ? '[' + _createOrderProvider.start.toString() + ']'
                          : "Request OTP",
                      style: TextStyle(fontSize: 30.h),
                    ),
                    onPressed: () async {
                      _createOrderProvider.startTimer();
                      bool status = await _createOrder(
                          phone: widget.phone,
                          title: widget.title,
                          bu: widget.bu,
                          billCode: widget.billCode,
                          amount: widget.amount);
                      if (status) {
                        print('ผ่าน');
                      } else {
                        print('error ไม่ส่ง OTP');
                      }
                    },
                    color: _createOrderProvider.getStatusOTP
                        ? Colors.grey
                        : Colors.cyan[300],
                    textColor: Colors.black,
                    // padding: EdgeInsets.all(3.0),
                    shape: RoundedRectangleBorder(
                      borderRadius: new BorderRadius.circular(18.0),
                      side: BorderSide(color: Colors.black54),
                    ),
                  ),
                )
              ],
            )
          ],
        ));
  }

  Widget buttonAction() {
    return Row(
      mainAxisAlignment: MainAxisAlignment.spaceAround,
      children: [
        SizedBox(
          height: 100.h,
          child: RaisedButton(
            child: Text(
              "ตกลง",
              style: TextStyleCustom.textStyleNG35(context),
            ),
            onPressed: () async {
              if (controller.text.length == 6) {
                _createOrderProvider.setLoading(value: true);
                print(widget.phone);
                print(_createOrderProvider.getOperations);
                print(controller.text.toString());
                final result = await callHTTP.apiSendConfirm(
                    phoneNumber: widget.phone,
                    operations: _createOrderProvider.getOperations,
                    otp: controller.text.toString());

                if (result['statusCode'] == 200) {
                  if (result['result']['operations'] == '') {
                    _createOrderProvider.setLoading(value: false);
                    PaymentConfirmComponent.showShortToast(
                        text: 'เกิดข้อผิดพลาด ไม่พบค่า operations');
                  } else {
                    final check = await callHTTP.apiCheckConfirm(
                        operations: result['result']['operations']);
                    if (result['statusCode'] == 200) {
                      if (check['result']['used'] == true) {
                        Navigator.pushReplacement(
                            context,
                            MaterialPageRoute(
                                builder: (context) => PaymentCompleted()));
                      } else {
                        _createOrderProvider.setLoading(value: false);
                        PaymentConfirmComponent.showShortToast(
                            text: 'เกิดข้อผิดพลาด รหัสยืนยันไม่ถูกต้อง');
                      }
                    } else {
                      _createOrderProvider.setLoading(value: false);
                      PaymentConfirmComponent.showShortToast(
                          text: 'เกิดข้อผิดพลาด โปรดลองอีกครั้ง');
                    }
                  }
                } else {
                  _createOrderProvider.setLoading(value: false);
                  PaymentConfirmComponent.showShortToast(
                      text: 'OTP ไม่ถูกต้อง');
                }
              } else {
                PaymentConfirmComponent.showShortToast(
                    text: 'กรอก OTP ไม่ครบถ้วน');
              }
            },
            color: Colors.blue[300],
            textColor: Colors.black,
            // padding: EdgeInsets.all(3.0),
            shape: RoundedRectangleBorder(
              borderRadius: new BorderRadius.circular(5.0),
              side: BorderSide(color: Colors.black12),
            ),
          ),
        ),
        SizedBox(
          height: 100.h,
          child: RaisedButton(
            child: Text(
              "ยกเลิก",
              style: TextStyleCustom.textStyleNG35(context),
            ),
            onPressed: () => {
              _createOrderProvider.timer.cancel(),
              Navigator.of(context).pop(),
            },
            color: Colors.grey[400],
            textColor: Colors.black,
            // padding: EdgeInsets.all(3.0),
            shape: RoundedRectangleBorder(
              borderRadius: new BorderRadius.circular(5.0),
              side: BorderSide(color: Colors.black12),
            ),
          ),
        )
      ],
    );
  }

  Future<bool> _createOrder(
      {String phone,
      String amount,
      String bu,
      String billCode,
      String title}) async {
    final result = await callHTTP.apiCreateOrder(
        phone: phone, amount: amount, billCode: billCode, bu: bu, title: title);
    print(result);
    if (result['statusCode'] == 200) {
      _createOrderProvider.setOperations(value: result['result']['operations']);
      return true;
    } else {
      return false;
    }
  }
}

==> likepoint_payment-0.0.2.tar.gz: lib/ui/payment_confirm/payment_confirm.dart <==
import 'dart:async';
import 'package:flutter/gestures.dart';
import 'package:intl/intl.dart';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:likepoint_payment/device_utils.dart';
import 'package:likepoint_payment/middle_ware/middle_payment.dart';
import 'package:likepoint_payment/provider/payment_confirm_provider.dart';
import 'package:likepoint_payment/text_style.dart';
import 'package:likepoint_payment/ui/custom_loading.dart';
import 'package:likepoint_payment/ui/payment_completed/payment_completed.dart';
import 'package:likepoint_payment/ui/payment_confirm/component/payment_confirm_component.dart';
import 'package:modal_progress_hud/modal_progress_hud.dart';
import 'package:provider/provider.dart';

class PaymentConfirmPage extends StatelessWidget {
  PaymentConfirmPage(
      {this.phone, this.amount, this.billCode, this.bu, this.title});
  final String phone;
  final String amount;
  final String billCode;
  final String bu;
  final String title;

  @override
  Widget build(BuildContext context) {
    return MultiProvider(
      providers: [
        ChangeNotifierProvider.value(value: CreateOrderProvider()),
      ],
      child: PaymentConfirm(
        phone: phone,
        amount: amount,
        billCode: billCode,
        bu: bu,
        title: title,
      ),
    );
  }
}

class PaymentConfirm extends StatefulWidget {
  PaymentConfirm({this.phone, this.amount, this.billCode, this.bu, this.title});

  final String phone;
  final String amount;
  final String billCode;
  final String bu;
  final String title;

  @override
  _PaymentConfirm createState() => _PaymentConfirm();
}

class _PaymentConfirm extends State<PaymentConfirm> {
  TextEditingController controller = TextEditingController();

  //////////////////// MIDDLE WARE /////////////////////////////
  HTTP callHTTP;
  //////////////////// PROVIDER ///////////////////////////////
  CreateOrderProvider _createOrderProvider;

  final f = new DateFormat('dd/MM/yyyy');
  int i = 0;

  @override
  void initState() {
    // TODO: implement initState
    super.initState();
    callHTTP = CallHTTP();
  }

  @override
  void didChangeDependencies() async {
    super.didChangeDependencies();
    _createOrderProvider = Provider.of<CreateOrderProvider>(context);
  }

  @override
  void dispose() {
    // TODO: implement dispose
    super.dispose();
    // _timer.cancel();
  }

  @override
  Widget build(BuildContext context) {
    ScreenUtil.init(context,
        designSize: Size(1080, 2340), allowFontScaling: false);
    return ModalProgressHUD(
      opacity: 0.5,
      inAsyncCall: _createOrderProvider.getLoading,
      progressIndicator: CustomLoading(),
      child: Scaffold(
        appBar: AppBar(
          backgroundColor: Colors.cyan,
          leading: InkWell(
            onTap: () => {
              Navigator.of(context).pop(false),
            },
            child: Icon(
              Icons.clear,
              size: 60.h,
            ),
          ),
          title: Text(
            'ยืนยันการชำระ',
          ),
          actions: [],
        ),
        body: GestureDetector(
          onTap: () {
            DeviceUtils.hideKeyboard(context);
          },
          child: SingleChildScrollView(
            child: Padding(
              padding: EdgeInsets.symmetric(horizontal: 100.w),
              child: Column(
                mainAxisAlignment: MainAxisAlignment.start,
                crossAxisAlignment: CrossAxisAlignment.start,
                children: <Widget>[
                  SizedBox(height: 100.h),
                  PaymentConfirmComponent.iconLikePoint(),
                  SizedBox(height: 100.h),
                  PaymentConfirmComponent.textLine1(
                      context: context,
                      text:
                          'เพื่อความปลอดภัยในการทำรายการชำระผ่านระบบออนไลน์ด้วย LIKE (Like Point)'),
                  SizedBox(height: 18.h),
                  PaymentConfirmComponent.textLine2(
                      context: context,
                      text:
                          'โปรดตรวจสอบความถูกต้องของข้อความยืนยันส่วนตัวของท่าน จากนั้นระบุรหัส OTP  (One Time Password)'),
                  PaymentConfirmComponent.textLine2(
                      context: context,
                      text: 'เพื่อเพิ่มความปลอดภัยในการทำรายการนี้'),
                  SizedBox(height: 40.h),
                  detail(
                      textTitle: 'ยอดรวม:',
                      textDetail: widget.amount + '  LIKE'),
                  detail(
                      textTitle: 'วันที่ชำระ:',
                      textDetail: f.format(DateTime.now()).toString()),
                  detail(
                      textTitle: 'เบอร์โทร:',
                      textDetail: '*******' +
                          widget.phone.substring(widget.phone.length - 3)),
                  detail(textTitle: 'ข้อความ:', textDetail: widget.title),
                  SizedBox(height: 40.h),
                  PaymentConfirmComponent.textLine5(
                      context: context,
                      text:
                          'กรุณากดปุ่ม  "Request OTP" เพื่อรับรหัสรักษาความปลอดภัย SMS-OTP'),
                  SizedBox(height: 40.h),
                  cardOTP(),
                  SizedBox(height: 100.h),
                  buttonAction(),
                  SizedBox(height: 100.h),
                  PaymentConfirmComponent.textLine5(
                      context: context,
                      text:
                          'กรณีท่านต้องการเปลี่ยนแปลงหมายเลขโทรศัพท์มือถือที่รับ OTP บริการชำระ LikePoint ได้ที่ APP Like Wallet สอบถามทีมสนับสนุน หรือ สอบถามรายละเอียดเพิ่มเติมได้ที่ \nโทร 098-0977-784 ต่อ 405'),
                  SizedBox(height: 40.h),
                ],
              ),
            ),
          ),
        ),
      ),
    );
  }

  Widget detail({String textTitle, String textDetail}) {
    return Container(
      child: Row(
        children: [
          Expanded(
            child: Align(
              alignment: Alignment.centerRight,
              child: PaymentConfirmComponent.textLine3(
                  context: context, text: textTitle),
            ),
          ),
          SizedBox(width: 20.w),
          Expanded(
            child: Align(
              alignment: Alignment.centerLeft,
              child: PaymentConfirmComponent.textLine4(
                  context: context, text: textDetail),
            ),
          ),
        ],
      ),
    );
  }

  Widget cardOTP() {
    return Container(
        decoration: BoxDecoration(border: Border.all(color: Colors.black12)),
        height: 300.h,
        width: MediaQuery.of(context).size.width,
        child: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          children: [
            PaymentConfirmComponent.textLine3(
                context: context,
                text: 'กรุณาระบุรหัสรักษาความปลอดภัย SMS-OTP ที่ได้รับ'),
            SizedBox(height: 20.h),
            Container(
                height: 80.h,
                width: 250.w,
                child: TextField(
                  controller: controller,
                  keyboardType: TextInputType.number,
                  textAlign: TextAlign.center,
                  textAlignVertical: TextAlignVertical.center,
                  inputFormatters: <TextInputFormatter>[
                    FilteringTextInputFormatter.digitsOnly,
                    LengthLimitingTextInputFormatter(6),
                  ], // Only numbers
                  style: TextStyleCustom.textStyleNG30(context),
                  decoration: InputDecoration(
                    isDense: true,
                    border: OutlineInputBorder(),
                    contentPadding: EdgeInsets.only(top: 20.h, bottom: 20.h),
                  ),
                )),
            SizedBox(height: 20.h),
            Row(
              mainAxisAlignment: MainAxisAlignment.center,
              children: [
                SizedBox(
                  height: 70.h,
                  child: RaisedButton(
                    child: Text(
                      _createOrderProvider.getStatusOTP
                          ? '[' + _createOrderProvider.start.toString() + ']'
                          : "Request OTP",
                      style: TextStyle(fontSize: 30.h),
                    ),
                    onPressed: () async {
                      if (_createOrderProvider.getStatusOTP) {
                        print('don t pass');
                      } else {
                        _createOrderProvider.startTimer();
                        bool status = await _createOrder(
                            phone: widget.phone,
                            title: widget.title,
                            bu: widget.bu,
                            billCode: widget.billCode,
                            amount: widget.amount);
                        if (status) {
                          print('ผ่าน');
                        } else {
                          print('error ไม่ส่ง OTP');
                        }
                      }
                    },
                    color: _createOrderProvider.getStatusOTP
                        ? Colors.grey
                        : Colors.cyan[300],
                    textColor: Colors.black,
                    // padding: EdgeInsets.all(3.0),
                    shape: RoundedRectangleBorder(
                      borderRadius: new BorderRadius.circular(18.0),
                      side: BorderSide(color: Colors.black54),
                    ),
                  ),
                )
              ],
            )
          ],
        ));
  }

  Widget buttonAction() {
    return Row(
      mainAxisAlignment: MainAxisAlignment.spaceAround,
      children: [
        SizedBox(
          height: 100.h,
          child: RaisedButton(
            child: Text(
              "ตกลง",
              style: TextStyleCustom.textStyleNG35(context),
            ),
            onPressed: () async {
              if (controller.text.length == 6) {
                _createOrderProvider.setLoading(value: true);
                print(widget.phone);
                print(_createOrderProvider.getOperations);
                print(controller.text.toString());
                final result = await callHTTP.apiSendConfirm(
                    phoneNumber: widget.phone,
                    operations: _createOrderProvider.getOperations,
                    otp: controller.text.toString());

                if (result['statusCode'] == 200) {
                  if (result['result']['operations'] == '') {
                    _createOrderProvider.setLoading(value: false);
                    PaymentConfirmComponent.showShortToast(
                        text: 'เกิดข้อผิดพลาด ไม่พบค่า operations');
                  } else {
                    if (result['statusCode'] == 200) {
                      await Future.delayed(Duration(seconds: 3));
                      callCheckAPI(
                          i: i, operations: result['result']['operations']);
                    } else {
                      _createOrderProvider.setLoading(value: false);
                      PaymentConfirmComponent.showShortToast(
                          text: 'เกิดข้อผิดพลาด โปรดลองอีกครั้ง');
                    }
                  }
                } else {
                  _createOrderProvider.setLoading(value: false);
                  PaymentConfirmComponent.showShortToast(
                      text: 'OTP ไม่ถูกต้อง');
                }
              } else {
                PaymentConfirmComponent.showShortToast(
                    text: 'กรอก OTP ไม่ครบถ้วน');
              }
            },
            color: Colors.blue[300],
            textColor: Colors.black,
            // padding: EdgeInsets.all(3.0),
            shape: RoundedRectangleBorder(
              borderRadius: new BorderRadius.circular(5.0),
              side: BorderSide(color: Colors.black12),
            ),
          ),
        ),
        SizedBox(
          height: 100.h,
          child: RaisedButton(
            child: Text(
              "ยกเลิก",
              style: TextStyleCustom.textStyleNG35(context),
            ),
            onPressed: () => {
              _createOrderProvider.timer.cancel(),
              Navigator.of(context).pop(),
            },
            color: Colors.grey[400],
            textColor: Colors.black,
            // padding: EdgeInsets.all(3.0),
            shape: RoundedRectangleBorder(
              borderRadius: new BorderRadius.circular(5.0),
              side: BorderSide(color: Colors.black12),
            ),
          ),
        )
      ],
    );
  }

  Future<bool> _createOrder(
      {String phone,
      String amount,
      String bu,
      String billCode,
      String title}) async {
    final result = await callHTTP.apiCreateOrder(
        phone: phone, amount: amount, billCode: billCode, bu: bu, title: title);
    print(result);
    if (result['statusCode'] == 200) {
      _createOrderProvider.setOperations(value: result['result']['operations']);
      return true;
    } else {
      return false;
    }
  }

  callCheckAPI({int i, String operations}) async {
    print(i);
    await Future.delayed(Duration(seconds: 3));
    if (i < 2) {
      final check = await callHTTP.apiCheckConfirm(operations: operations);
      if (check['result']['used'] == true) {
        Navigator.pushReplacement(context,
            MaterialPageRoute(builder: (context) => PaymentCompleted()));
      } else {
        i++;
        callCheckAPI(i: i, operations: operations);
      }
    } else {
      _createOrderProvider.setLoading(value: false);
      PaymentConfirmComponent.showShortToast(
          text: 'เกิดข้อผิดพลาด รหัสยืนยันไม่ถูกต้อง');
    }
  }
}
